import app from "../app.js";
import debugLib from "debug";
import http from "http";
const debug = debugLib("your-project-name:server");
import dotenv from "dotenv";
import { Server } from "socket.io";
dotenv.config();

/**
 * Get port from environment and store in Express.
 */

const port = process.env.PORT || "3001";
console.log("App is running on port", port);
app.set("port", port);

/**
 * Create HTTP server.
 */

const server = http.createServer(app);

/**
 * Listen on provided port, on all network interfaces.
 */

server.listen(port);
server.on("error", onError);
server.on("listening", onListening);

const io = new Server(server, {
  maxHttpBufferSize: 1e9,
  //transports: ['websocket'], upgrade: false,
  pingInterval: 1000 * 60 * 5,
  pingTimeout: 1000 * 60 * 3,
  cors: {
    origin: "*",
  },
});

/**
 * Event listener for HTTP server "error" event.
 * @param {Object} error - The error object containing details about the error.
 * @throws {Error} - Rethrows the error if it's not a listening error.
 */

function onError(error) {
  if (error.syscall !== "listen") {
    throw error;
  }

  let bind = typeof port === "string" ? "Pipe " + port : "Port " + port;

  // handle specific listen errors with friendly messages
  switch (error.code) {
    case "EACCES":
      console.error(bind + " requires elevated privileges");
      process.exit(1);
      break;
    case "EADDRINUSE":
      console.error(bind + " is already in use");
      process.exit(1);
      break;
    default:
      throw error;
  }
}

/**
 * Event listener for HTTP server "listening" event.
 */

function onListening() {
  const addr = server.address();
  const bind = typeof addr === "string" ? "pipe " + addr : "port " + addr.port;
  debug("Listening on " + bind);
}
